@@ -19,7 +19,7 @@ Arnolfini.archivePopUp.showMessage = function (href)
     var continueButton = $('<div class="continueButton">Continue</div>');
     
     $(cancelButton).click(Arnolfini.archivePopUp.closeMessage);
-    $(continueButton).click(function () {window.location = href})
+    $(continueButton).click(function () {window.location = href + '?showall=true'})
     
     $(messageDiv).text(message);
     $(popupDiv).append(title);
